<?php
/**
* @package		EasySocial
* @copyright	Copyright (C) 2010 - 2018 Stack Ideas Sdn Bhd. All rights reserved.
* @license		GNU/GPL, see LICENSE.php
* EasySocial is free software. This version may have been modified pursuant
* to the GNU General Public License, and as distributed it includes or
* is derivative of works licensed under the GNU General Public License or
* other free or open source software licenses.
* See COPYRIGHT.php for copyright notices and details.
*/
defined('_JEXEC') or die('Unauthorized Access');

ES::import('admin:/includes/apps/apps');

class SocialUserAppAkismet extends SocialAppItem
{
	/**
	 * Checks for spam in conversation
	 *
	 * @since	2.2.3
	 * @access	public
	 */
	public function onConversationValidate(&$conversation)
	{
		$this->params = $this->getParams();

		// Never check spammers for site admin.
		if (ES::user()->isSiteAdmin()) {
			return false;
		}

		if (!$this->params->get('api_key') || !$this->params->get('enable_conversation', true)) {
			return false;
		}

		$akismet = ES::akismet($this->params->get('api_key'), JURI::root());
		$isSpam = $akismet->check($conversation->content);

		// Response returned needs to be 0 to be flagged as spam
		if ($isSpam) {
			$conversation->setError(JText::_('PLG_APP_USER_AKISMET_SPAM_MESSAGE'));
			return true;
		}

		// return false if all good.
		return false;
	}

	/**
	 * Checks for spam user when they comments on the site.
	 *
	 * @since   2.2.3
	 * @access  public
	 */
	public function onUserValidateCommentSpam($comment)
	{
		$this->params = $this->getParams();

		// Never check spammers for site admin.
		if (ES::user()->isSiteAdmin()) {
			return false;
		}

		if (!$this->params->get('api_key') || !$this->params->get('enable_comments', true)) {
			return false;
		}

		$akismet = ES::akismet($this->params->get('api_key'), JURI::root());
		$isSpam = $akismet->check($comment->comment);

		// We'll need to return false here in order to capture error messages.
		if ($isSpam) {
			return true;
		}

		// return false if all good.
		return false;
	}
}
